==> qt-everywhere-opensource-src-4.6.0.tar.gz: qt-everywhere-opensource-src-4.6.0/tools/qtconfig/previewframe.h <==
/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the tools applications of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial Usage
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef PREVIEWFRAME_H
#define PREVIEWFRAME_H

#include "previewwidget.h"

#include <QMdiArea>

QT_BEGIN_NAMESPACE

class PreviewFrame;
class Workspace : public QMdiArea
{
    Q_OBJECT

public:
    Workspace( PreviewFrame* parent = 0, const char* name = 0 );
    ~Workspace() {}

protected:
    void paintEvent( QPaintEvent* );
private:
    PreviewFrame *previewFrame;
};

class PreviewFrame : public QFrame
{
    Q_OBJECT

public:
    PreviewFrame( QWidget *parent = 0, const char *name = 0 );
    void setPreviewPalette(QPalette);
    void setPreviewVisible(bool val);
    QString previewText() const;
    PreviewWidget *widget() const { return previewWidget; }
private:
    Workspace   *workspace;
    PreviewWidget 	*previewWidget;
    QString m_previewWindowText;
};

QT_END_NAMESPACE

#endif

==> qt-everywhere-opensource-src-4.8.4.tar.gz: qt-everywhere-opensource-src-4.8.4/tools/qtconfig/previewframe.h <==
/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the tools applications of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef PREVIEWFRAME_H
#define PREVIEWFRAME_H

#include <QMdiArea>

QT_BEGIN_NAMESPACE

class PreviewFrame;
class Workspace : public QMdiArea
{
    Q_OBJECT

public:
    Workspace(PreviewFrame *parent = 0);
    ~Workspace() {}

protected:
    void paintEvent(QPaintEvent *);
private:
    PreviewFrame *previewFrame;
};

class PreviewWidget;
class PreviewFrame : public QFrame
{
    Q_OBJECT

public:
    PreviewFrame(QWidget *parent = 0);
    void setPreviewPalette(QPalette);
    void setPreviewVisible(bool val);
    QString previewText() const;
    PreviewWidget *widget() const { return previewWidget; }
private:
    Workspace *workspace;
    PreviewWidget *previewWidget;
    QString m_previewWindowText;
};

QT_END_NAMESPACE

#endif
